summary | shortlog | log | commit | commitdiff | tree
raw | patch | inline | side by side (parent: 2566956)
raw | patch | inline | side by side (parent: 2566956)
author | Suman Anna <s-anna@ti.com> | |
Thu, 21 Feb 2019 02:40:11 +0000 (20:40 -0600) | ||
committer | Suman Anna <s-anna@ti.com> | |
Mon, 25 Feb 2019 19:15:11 +0000 (13:15 -0600) |
The K3 AM65x family of SoCs have the next generation of the PRU-ICSS
processor subsystem capable of supporting Gigabit Ethernet, and is
commonly referred to as ICSSG. These SoCs contain typically three
ICSSG instances named ICSSG0, ICSSG1 and ICSSG2. The three ICSSGs are
identical to each other for the most part with minor SoC integration
differences and capabilities. The ICSSG2 supports slightly enhanced
features like SGMII mode Ethernet, while the ICSS0 and ICSSG1 instances
are limited to MII mode only.
The ICSSGs on K3 AM65x SoCs are in general super-sets of the PRUSS on the
AM57xx/66AK2G SoCs. They include two additional auxiliary PRU cores called
RTUs and few other additional sub-modules. The interrupt integration is
also different on the K3 AM65x SoCs and are propagated through various
SoC-level Interrupt Router and Interrupt Aggregator blocks. Other IP level
differences include different constant tables, differences in system event
interrupt input sources etc. They also do not have a programmable module
reset line like those present on AM33xx/AM43xx SoCs. The modules are reset
just like any other IP with the SoC's global cold/warm resets.
The existing pruss_soc_bus and pruss platform drivers have been updated to
support these new ICSSG instances through new AM65x specific compatibles.
A build dependency with ARCH_K3 is added to enable building all the
existing PRUSS platform drivers for this ARMv8 platform.
Signed-off-by: Suman Anna <s-anna@ti.com>
processor subsystem capable of supporting Gigabit Ethernet, and is
commonly referred to as ICSSG. These SoCs contain typically three
ICSSG instances named ICSSG0, ICSSG1 and ICSSG2. The three ICSSGs are
identical to each other for the most part with minor SoC integration
differences and capabilities. The ICSSG2 supports slightly enhanced
features like SGMII mode Ethernet, while the ICSS0 and ICSSG1 instances
are limited to MII mode only.
The ICSSGs on K3 AM65x SoCs are in general super-sets of the PRUSS on the
AM57xx/66AK2G SoCs. They include two additional auxiliary PRU cores called
RTUs and few other additional sub-modules. The interrupt integration is
also different on the K3 AM65x SoCs and are propagated through various
SoC-level Interrupt Router and Interrupt Aggregator blocks. Other IP level
differences include different constant tables, differences in system event
interrupt input sources etc. They also do not have a programmable module
reset line like those present on AM33xx/AM43xx SoCs. The modules are reset
just like any other IP with the SoC's global cold/warm resets.
The existing pruss_soc_bus and pruss platform drivers have been updated to
support these new ICSSG instances through new AM65x specific compatibles.
A build dependency with ARCH_K3 is added to enable building all the
existing PRUSS platform drivers for this ARMv8 platform.
Signed-off-by: Suman Anna <s-anna@ti.com>
drivers/soc/ti/Kconfig | patch | blob | history | |
drivers/soc/ti/pruss.c | patch | blob | history | |
drivers/soc/ti/pruss_soc_bus.c | patch | blob | history |
diff --git a/drivers/soc/ti/Kconfig b/drivers/soc/ti/Kconfig
index 0b67bde174b584c5cf4ff148a9f591ab0bd3147e..5c16f865637b82af8044c8abc8cc9f97e9bcd482 100644 (file)
--- a/drivers/soc/ti/Kconfig
+++ b/drivers/soc/ti/Kconfig
config TI_PRUSS
tristate "TI PRU-ICSS Subsystem Platform drivers"
- depends on SOC_AM33XX || SOC_AM43XX || SOC_DRA7XX || ARCH_KEYSTONE
+ depends on SOC_AM33XX || SOC_AM43XX || SOC_DRA7XX || ARCH_KEYSTONE || ARCH_K3
select MFD_SYSCON
help
TI PRU-ICSS Subsystem platform specific support.
diff --git a/drivers/soc/ti/pruss.c b/drivers/soc/ti/pruss.c
index f78dbf037be0c3fb9ec5638be5159b6e1144d333..770863040e2150abe3499ced4be75ac003fff659 100644 (file)
--- a/drivers/soc/ti/pruss.c
+++ b/drivers/soc/ti/pruss.c
if (!dev->parent)
return ERR_PTR(-ENODEV);
- /* rudimentary check to make sure rproc handle is for a PRU */
- if (!strstr(dev_name(dev->parent), "pru"))
+ /* rudimentary check to make sure rproc handle is for a PRU or RTU */
+ if (!strstr(dev_name(dev->parent), "pru") &&
+ !strstr(dev_name(dev->parent), "rtu"))
return ERR_PTR(-ENODEV);
ppdev = to_platform_device(dev->parent->parent);
{ .compatible = "ti,am4376-pruss", .data = &am437x_match_data, },
{ .compatible = "ti,am5728-pruss", .data = NULL, },
{ .compatible = "ti,k2g-pruss", .data = NULL, },
+ { .compatible = "ti,am654-icssg", .data = NULL, },
{ /* sentinel */ },
};
MODULE_DEVICE_TABLE(of, pruss_of_match);
index 47545fc13b3710c3ccf9f327b63e3eadc1479624..fc1d58caf03c19973585cc64fdf040c248218dec 100644 (file)
{ .compatible = "ti,am4376-pruss-soc-bus", .data = &am437x_data, },
{ .compatible = "ti,am5728-pruss-soc-bus", .data = &am57xx_data, },
{ .compatible = "ti,k2g-pruss-soc-bus", .data = &k2g_data, },
+ { .compatible = "ti,am654-icssg-soc-bus", .data = &k2g_data, },
{ /* sentinel */ },
};
MODULE_DEVICE_TABLE(of, pruss_soc_bus_of_match);